@@ -1,6 +1,7 @@
-import os
 import numpy as np
 from scipy.stats import gaussian_kde
+import scipy.stats as stats
+
 import warnings
 
 try:
@@ -95,6 +96,8 @@ def joyplot(data, column=None, by=None, grid=False,
             title=None,
             colormap=None,
             color=None,
+            normalize=True,
+            floc=None,
             **kwds):
     """
     Draw joyplot of a DataFrame, or appropriately nested collection,
@@ -173,7 +176,8 @@ def joyplot(data, column=None, by=None, grid=False,
         grouped = data.groupby(by)
         if column is None:
             # Remove the groupby key. It's not automatically removed by pandas.
-            column = list(data.columns).remove(by)
+            column = list(data.columns)
+            column.remove(by)
         converted, _labels, sublabels = _grouped_df_to_standard(grouped, column)
         if labels is None:
             labels = _labels
@@ -247,13 +251,16 @@ def joyplot(data, column=None, by=None, grid=False,
                     title=title,
                     colormap=colormap,
                     color=color,
+                    normalize=normalize,
+                    floc=floc,
                     **kwds)
 
 ###########################################
 
 def plot_density(ax, x_range, v, kind="kde", bw_method=None,
                  bins=50,
-                 fill=False, linecolor=None, clip_on=True, **kwargs):
+                 fill=False, linecolor=None, clip_on=True,
+                 normalize=True, floc=None,**kwargs):
     """ Draw a density plot given an axis, an array of values v and an array
         of x positions where to return the estimated density.
     """
@@ -289,6 +296,17 @@ def plot_density(ax, x_range, v, kind="kde", bw_method=None,
             else:
                 raise e
 
+    elif kind == "lognorm":
+        if floc is not None:
+            lnparam = stats.lognorm.fit(v,loc=floc)
+        else:
+            lnparam = stats.lognorm.fit(v)
+
+        lpdf = stats.lognorm.pdf(x_range,lnparam[0],lnparam[1],lnparam[2])
+        if normalize:
+            y = lpdf/lpdf.sum()
+        else:
+            y = lpdf
     elif kind == "counts":
         y, bin_edges = np.histogram(v, bins=bins, range=(min(x_range), max(x_range)))
         # np.histogram returns the edges of the bins.
@@ -310,6 +328,7 @@ def plot_density(ax, x_range, v, kind="kde", bw_method=None,
         raise NotImplementedError
 
     if fill:
+
         ax.fill_between(x_range, 0.0, y, clip_on=clip_on, **kwargs)
 
         # Hack to have a border at the bottom at the fill patch
@@ -330,6 +349,7 @@ def plot_density(ax, x_range, v, kind="kde", bw_method=None,
 
     ax.plot(x_range, y, clip_on=clip_on, **kwargs)
 
+
 ###########################################
 
 def _joyplot(data,
@@ -348,6 +368,8 @@ def _joyplot(data,
              title=None,
              legend=False, loc="upper right",
              colormap=None, color=None,
+             normalize=True,
+             floc=None,
              **kwargs):
     """
     Internal method.
@@ -432,6 +454,7 @@ def _joyplot(data,
         assert all(len(g) == len(colormap) for g in data)
 
     for i, group in enumerate(data):
+
         a = _axes[i]
         group_zorder = i
         if fade:
@@ -476,7 +499,6 @@ def _joyplot(data,
                              zorder=element_zorder, color=element_color,
                              bins=bins, **kwargs)
 
-
         # Setup the current axis: transparency, labels, spines.
         col_name = None if labels is None else labels[i]
         _setup_axis(a, global_x_range, col_name=col_name, grid=ygrid,
@@ -559,6 +581,5 @@ def _joyplot(data,
     h_pad = 5 + (- 5*(1 + overlap))
     fig.tight_layout(h_pad=h_pad)
 
-
     return fig, _axes
 
